ports/misc/migrationtools/patches/patch-migrate_passwd_pl

31 lines
976 B
Text

Our master.passwd differs from linux shadow, reflect this.
--- migrate_passwd.pl.orig Wed Jan 25 05:18:16 2006
+++ migrate_passwd.pl Fri Mar 2 23:42:40 2012
@@ -32,7 +32,7 @@
# SUCH DAMAGE.
#
#
# Password migration tool. Migrates /etc/shadow as well, if it exists.
#
# Thanks to Peter Jacob Slot <peter@vision.auk.dk>.
#
@@ -185,7 +185,7 @@ if (OUTFILE != STDOUT) { close(OUTFILE); }
sub read_shadow_file
{
- open(SHADOW, "/etc/shadow") || return;
+ open(SHADOW, "/etc/master.passwd") || return;
while(<SHADOW>) {
chop;
($shadowUser) = split(/:/, $_);
@@ -196,7 +196,7 @@ sub read_shadow_file
sub dump_shadow_attributes
{
- local($HANDLE, $user, $pwd, $lastchg, $min, $max, $warn, $inactive, $expire, $flag) = @_;
+ local($HANDLE, $user, $pwd, $uid, $gid, $class, $max, $expire, $gecos, $home, $shell) = @_;
print $HANDLE "objectClass: shadowAccount\n";
if ($pwd) {
@@ -32,7 +32,7 @@
#
#
-# Password migration tool. Migrates /etc/shadow as well, if it exists.
+# Password migration tool. Migrates /etc/master.passwd as well, if it exists.
#
# Thanks to Peter Jacob Slot <peter@vision.auk.dk>.